"""
CH E 210D Final Project
Isaac Zakaria
11 December 2019

"""
#import python modules
import numpy as np
import time
import multiprocessing as mp
#import atomwrite
import matplotlib.pyplot as plt

#import compiled fortran library
import finallib
#import python library
import final
import atomwrite

import sys
import os

def MDRunWrapperPDB((M,lambdaD,RandomSeed,PDBName)):
    
    # in the infinitely screened limit, kill the Coulomb term
    if lambdaD == 0:
        final.epsilonC = 0
        final.lambdaD = 1
    else:
        final.lambdaD = lambdaD
        final.epsilonC = 10
        
    final.M = M
    np.random.seed(RandomSeed)
    
    # non-global simulation variables
    rho = 0.8
    N = 300
    T = 1.0
    dt = 0.001
    NStepsEquil = 25000
    NStepsProd = 20000
    # global variables
    final.L = np.cbrt(N/rho)
    final.Cut = 2.5
    final.qList = (0,0,1,0,0,-1)*50
    
    Pos0 = final.InitPositions(N, final.L)
    PEnergies, AvgAtomCoord, MSDMatrix, DCoeff = final.MDRunPDB(Pos0, N, T, rho, dt, NStepsEquil, NStepsProd, PDBName)
    
    return M, lambdaD, PEnergies, AvgAtomCoord, MSDMatrix, DCoeff


ChainLengths = [12] # number of monomers per chain
lambdaDList = [0,100] # charge screening
SeedList = [342324]

# generate unique M, lambdaD pairs
argList = ()

for M in ChainLengths:
    for lambdaD in lambdaDList:
        for RandomSeed in SeedList:
            PDBName = "M"+str(M)+"lambdaD"+str(lambdaD)+"seed"+str(RandomSeed)
            argList = argList + ((M, lambdaD, RandomSeed, PDBName),)

# set number of workers for multiprocessing
numWorkers = mp.cpu_count()

# use multiprocessing to delegate one iteration to each available worker
if __name__ == '__main__':
    p = mp.Pool(processes = numWorkers)
    print "mp pool started"
    T0 = time.time()
    A = p.map_async(MDRunWrapperPDB, argList).get(None)
    p.close()
    p.join()
    T1 = time.time()
    print "mp done; elapsed time in minutes..."
    print (T1-T0)/60